<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>NotificationActionsComboWidget</name>
    <message>
        <location filename="../notificationwidgets.cpp" line="103"/>
        <source>Actions:</source>
        <translation>Ενέργειες:</translation>
    </message>
    <message>
        <location filename="../notificationwidgets.cpp" line="122"/>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
</context>
<context>
    <name>Notifyd</name>
    <message>
        <location filename="../notifyd.cpp" line="226"/>
        <source>Clear All</source>
        <translation>Εκκαθάριση όλων</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="234"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message numerus="yes">
        <location filename="../notifyd.cpp" line="241"/>
        <location filename="../notifyd.cpp" line="299"/>
        <location filename="../notifyd.cpp" line="319"/>
        <source>%n Unattended Notification(s)</source>
        <translation>
            <numerusform>%n Ανεπίβλεπτη-ες ειδοποίηση-εις</numerusform>
            <numerusform>%n Ανεπίβλεπτη-ες ειδοποίηση-εις</numerusform>
        </translation>
    </message>
</context>
</TS>
